@@ -35,7 +35,8 @@ class CrawlerConfig(object):
             ("hw", "str", ""),
             ("ff", "str", ""),
             ("nk", "str", ""),
-            ("ww", "str", "")
+            ("ww", "str", ""),
+            ("dd", "str", "")
         ],
         'Crawljobs': [
             ("autostart", "bool", "True"),
@@ -66,6 +67,10 @@ class CrawlerConfig(object):
             ("url", "str", ""),
             ("api", "str", "")
         ],
+        'Overseerr': [
+            ("url", "str", ""),
+            ("api", "str", "")
+        ],
         'ContentAll': [
             ("quality", "str", "1080p"),
             ("search", "int", "10"),
@@ -98,6 +103,9 @@ class CrawlerConfig(object):
             ("regex", "bool", "False"),
             ("hoster_fallback", "bool", "False")
         ],
+        'CustomDD': [
+            ("hoster_fallback", "bool", "False")
+        ],
         'CustomF': [
             ("interval", "int", "6"),
             ("search", "int", "3")
