@@ -62,7 +62,7 @@ def set_files(set_configpath):
 
 def set_sites():
     global sites
-    sites = ["SJ", "DJ", "SF", "BY", "FX", "FF", "HW", "NK", "WW"]
+    sites = ["SJ", "DJ", "SF", "BY", "FX", "FF", "HW", "NK", "WW", "DD"]
 
 
 def set_device(set_device):
