@@ -3,14 +3,15 @@
 # Projekt von https://github.com/rix1337
 # Dieses Modul stellt die Web-Suche für alle integrierten Hostnamen bereit.
 
+import json
 import re
 
 from bs4 import BeautifulSoup
-from rapidfuzz import fuzz
 
 from feedcrawler.common import check_is_site
 from feedcrawler.common import encode_base64
 from feedcrawler.common import sanitize
+from feedcrawler.common import simplified_search_term_in_title
 from feedcrawler.config import CrawlerConfig
 from feedcrawler.sites.shared.internal_feed import by_search_results
 from feedcrawler.sites.shared.internal_feed import fx_content_to_soup
@@ -22,11 +23,11 @@ from feedcrawler.url import get_urls_async
 from feedcrawler.url import post_url
 
 
-def get(title, bl_only=False, sj_only=False, fast_only=False, slow_only=False):
-    if fast_only:
-        slow_only = False
-    if slow_only:
-        fast_only = False
+def get(title, only_content_all=False, only_content_shows=False, only_fast=False, only_slow=False):
+    if only_fast:
+        only_slow = False
+    if only_slow:
+        only_fast = False
 
     hostnames = CrawlerConfig('Hostnames')
     by = hostnames.get('by')
@@ -34,6 +35,7 @@ def get(title, bl_only=False, sj_only=False, fast_only=False, slow_only=False):
     hw = hostnames.get('hw')
     nk = hostnames.get('nk')
     sj = hostnames.get('sj')
+    sf = hostnames.get('sf')
 
     specific_season = re.match(r'^(.*),(s\d{1,3})$', title.lower())
     specific_episode = re.match(r'^(.*),(s\d{1,3}e\d{1,3})$', title.lower())
@@ -48,10 +50,8 @@ def get(title, bl_only=False, sj_only=False, fast_only=False, slow_only=False):
     else:
         special = None
 
-    bl_final = []
-    sj_final = []
-
-    if not sj_only:
+    content_all_results = []
+    if not only_content_shows:
         mb_query = sanitize(title).replace(" ", "+")
         if special:
             bl_query = mb_query + "+" + special
@@ -82,9 +82,9 @@ def get(title, bl_only=False, sj_only=False, fast_only=False, slow_only=False):
         else:
             hw_search = None
 
-        if fast_only:
+        if only_fast:
             fx_search = None
-        if slow_only:
+        if only_slow:
             by_search = None
             hw_search = None
 
@@ -99,11 +99,11 @@ def get(title, bl_only=False, sj_only=False, fast_only=False, slow_only=False):
             if check_is_site(res) == 'BY':
                 by_results = by_search_results(res, by)
             elif check_is_site(res) == 'FX':
-                fx_results = fx_search_results(fx_content_to_soup(res))
+                fx_results = fx_search_results(fx_content_to_soup(res), bl_query)
             elif check_is_site(res) == 'HW':
                 hw_results = hw_search_results(res)
 
-        if nk and not slow_only:
+        if nk and not only_slow:
             nk_search = post_url('https://' + nk + "/search",
                                  data={'search': bl_query})
             nk_results = nk_search_results(nk_search, 'https://' + nk + '/')
@@ -166,10 +166,12 @@ def get(title, bl_only=False, sj_only=False, fast_only=False, slow_only=False):
             res = {"payload": result[1], "title": result[2]}
             results.append(res)
             i += 1
-        bl_final = results
+        content_all_results = results
 
-    if not bl_only:
-        if sj and not slow_only:
+    content_shows_sj_results = []
+    content_shows_sf_results = []
+    if not only_content_all:
+        if sj and not only_slow:
             sj_query = sanitize(title).replace(" ", "+")
             sj_search = get_url('https://' + sj + '/serie/search?q=' + sj_query)
             try:
@@ -187,15 +189,40 @@ def get(title, bl_only=False, sj_only=False, fast_only=False, slow_only=False):
         results = []
         for result in sj_results:
             r_title = result.text
-            r_rating = fuzz.ratio(title.lower(), r_title)
-            if r_rating > 40:
+            if simplified_search_term_in_title(title, r_title):
                 res = {"payload": encode_base64(result['href'] + "|" + r_title + "|" + str(special)),
                        "title": r_title + append}
                 results.append(res)
                 i += 1
-        sj_final = results
+        content_shows_sj_results = results
 
-    return bl_final, sj_final
+        if sf and not only_slow:
+            sf_query = sanitize(title)
+            sf_search = get_url('https://' + sf + '/api/v2/search?q=' + sf_query + '&ql=DE')
+            try:
+                sf_results = json.loads(sf_search)["result"]
+            except:
+                sf_results = []
+        else:
+            sf_results = []
+
+        if special:
+            append = " (" + special + ")"
+        else:
+            append = ""
+        i = 0
+        results = []
+        for result in sf_results:
+            r_title = result["title"]
+            if simplified_search_term_in_title(title, r_title):
+                r_url = "https://" + sf + "/" + result["url_id"]
+                res = {"payload": encode_base64(r_url + "|" + r_title + "|" + str(special)),
+                       "title": r_title + append}
+                results.append(res)
+                i += 1
+        content_shows_sf_results = results
+
+    return content_all_results, content_shows_sj_results, content_shows_sf_results
 
 
 def rate(title, ignore=False):
