@@ -12,7 +12,6 @@ import time
 from functools import wraps
 
 from flask import Flask, request, redirect, render_template, send_from_directory, jsonify, Response
-from flask_cors import CORS
 from passlib.hash import pbkdf2_sha256
 from requests.packages.urllib3 import disable_warnings as disable_request_warnings
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
@@ -81,7 +80,6 @@ def app_container():
         return decorated
 
     app = Flask(__name__, template_folder=os.path.join(base_dir, 'web/dist'))
-    CORS(app)
 
     @app.route(prefix + '/', defaults={'path': ''}, methods=['GET'])
     @app.route(prefix + '/<path:path>')
@@ -217,10 +215,12 @@ def app_container():
                 hosters = CrawlerConfig('Hosters')
                 alerts = CrawlerConfig('Notifications')
                 ombi = CrawlerConfig('Ombi')
+                overseerr = CrawlerConfig('Overseerr')
                 crawljobs = CrawlerConfig('Crawljobs')
                 mb_conf = CrawlerConfig('ContentAll')
                 sj_conf = CrawlerConfig('ContentShows')
                 dj_conf = CrawlerConfig('CustomDJ')
+                dd_conf = CrawlerConfig('CustomDD')
                 f_conf = CrawlerConfig('CustomF')
                 return jsonify(
                     {
@@ -266,6 +266,10 @@ def app_container():
                                 "url": ombi.get("url"),
                                 "api": ombi.get("api"),
                             },
+                            "overseerr": {
+                                "url": overseerr.get("url"),
+                                "api": overseerr.get("api"),
+                            },
                             "crawljobs": {
                                 "autostart": crawljobs.get("autostart"),
                                 "subdir": crawljobs.get("subdir"),
@@ -303,6 +307,9 @@ def app_container():
                                 "regex": dj_conf.get("regex"),
                                 "hoster_fallback": dj_conf.get("hoster_fallback"),
                             },
+                            "dd": {
+                                "hoster_fallback": dd_conf.get("hoster_fallback"),
+                            },
                             "f": {
                                 "interval": to_int(f_conf.get("interval")),
                                 "search": to_int(f_conf.get("search"))
@@ -317,7 +324,6 @@ def app_container():
                 data = request.json
 
                 section = CrawlerConfig("FeedCrawler")
-
                 section.save(
                     "auth_user", to_str(data['general']['auth_user']))
 
@@ -363,19 +369,16 @@ def app_container():
                 section.save("packages_per_myjd_page", to_str(data['general']['packages_per_myjd_page']))
 
                 section = CrawlerConfig("Crawljobs")
-
                 section.save("autostart", to_str(data['crawljobs']['autostart']))
                 section.save("subdir", to_str(data['crawljobs']['subdir']))
 
                 section = CrawlerConfig("Notifications")
-
                 section.save("pushbullet", to_str(data['alerts']['pushbullet']))
                 section.save("pushover", to_str(data['alerts']['pushover']))
                 section.save("telegram", to_str(data['alerts']['telegram']))
                 section.save("homeassistant", to_str(data['alerts']['homeassistant']))
 
                 section = CrawlerConfig("Hosters")
-
                 section.save("rapidgator", to_str(data['hosters']['rapidgator']))
                 section.save("turbobit", to_str(data['hosters']['turbobit']))
                 section.save("uploaded", to_str(data['hosters']['uploaded']))
@@ -391,10 +394,13 @@ def app_container():
                 section.save("k2s", to_str(data['hosters']['k2s']))
 
                 section = CrawlerConfig("Ombi")
-
                 section.save("url", to_str(data['ombi']['url']))
                 section.save("api", to_str(data['ombi']['api']))
 
+                section = CrawlerConfig("Overseerr")
+                section.save("url", to_str(data['overseerr']['url']))
+                section.save("api", to_str(data['overseerr']['api']))
+
                 section = CrawlerConfig("ContentAll")
                 section.save("quality", to_str(data['mb']['quality']))
                 section.save("search", to_str(data['mb']['search']))
@@ -422,7 +428,6 @@ def app_container():
                 section.save("hoster_fallback", to_str(data['mb']['hoster_fallback']))
 
                 section = CrawlerConfig("ContentShows")
-
                 section.save("quality", to_str(data['sj']['quality']))
                 section.save("rejectlist", to_str(data['sj']['ignore']).lower())
                 section.save("regex", to_str(data['sj']['regex']))
@@ -431,19 +436,19 @@ def app_container():
                 section.save("hoster_fallback", to_str(data['sj']['hoster_fallback']))
 
                 section = CrawlerConfig("CustomDJ")
-
                 section.save("quality", to_str(data['dj']['quality']))
                 section.save("rejectlist", to_str(data['dj']['ignore']).lower())
                 section.save("regex", to_str(data['dj']['regex']))
                 section.save("hoster_fallback", to_str(data['dj']['hoster_fallback']))
 
-                section = CrawlerConfig("CustomF")
+                section = CrawlerConfig("CustomDD")
+                section.save("hoster_fallback", to_str(data['dd']['hoster_fallback']))
 
+                section = CrawlerConfig("CustomF")
                 interval = to_str(data['f']['interval'])
                 if to_int(interval) < 6:
                     interval = '6'
                 section.save("interval", interval)
-
                 search_depth = to_str(data['f']['search'])
                 if to_int(search_depth) > 7:
                     search_depth = '7'
@@ -530,6 +535,7 @@ def app_container():
                 ww = hostnames.get('ww')
                 nk = hostnames.get('nk')
                 by = hostnames.get('by')
+                dd = hostnames.get('dd')
 
                 fx = fx.replace("f", "F", 1).replace("d", "D", 1).replace("x", "X", 1)
                 hw = hw.replace("h", "H", 1).replace("d", "D", 1).replace("w", "W", 1)
@@ -540,6 +546,8 @@ def app_container():
                 ww = ww.replace("w", "W", 2)
                 nk = nk.replace("n", "N", 1).replace("k", "K", 1)
                 by = by.replace("b", "B", 1)
+                dd = dd.replace("d", "D", 2).replace("l", "L", 1)
+
                 bl = ' / '.join(list(filter(None, [fx, ff, hw, ww, nk, by])))
                 s = ' / '.join(list(filter(None, [sj, sf])))
                 f = ' / '.join(list(filter(None, [ff, sf])))
@@ -563,6 +571,8 @@ def app_container():
                     nk = "Nicht gesetzt!"
                 if not by:
                     by = "Nicht gesetzt!"
+                if not dd:
+                    dd = "Nicht gesetzt!"
                 if not bl:
                     bl = "Nicht gesetzt!"
                 if not s:
@@ -578,6 +588,7 @@ def app_container():
                             "dj": dj,
                             "sf": sf,
                             "by": by,
+                            "dd": dd,
                             "fx": fx,
                             "hw": hw,
                             "ff": ff,
@@ -674,6 +685,8 @@ def app_container():
     def search_title(title):
         if request.method == 'POST':
             try:
+                if len(title) < 3:
+                    return "Search term too short!", 400
                 data = json.loads(request.data)
                 slow_only = data['slow_only']
                 fast_only = data['fast_only']
@@ -681,12 +694,13 @@ def app_container():
                 slow_only = False
                 fast_only = False
             try:
-                results = search.get(title, slow_only=slow_only, fast_only=fast_only)
+                results = search.get(title, only_slow=slow_only, only_fast=fast_only)
                 return jsonify(
                     {
                         "results": {
                             "bl": results[0],
-                            "sj": results[1]
+                            "sj": results[1],
+                            "sf": results[2]
                         }
                     }
                 ), 200
@@ -739,9 +753,9 @@ def app_container():
         else:
             return "Failed", 405
 
-    @app.route(prefix + "/api/download_sj/<payload>", methods=['POST'])
+    @app.route(prefix + "/api/download_s/<payload>", methods=['POST'])
     @requires_auth
-    def download_sj(payload):
+    def download_s(payload):
         if request.method == 'POST':
             try:
                 if feedcrawler.search.shared.content_shows.download(payload):
@@ -1049,6 +1063,9 @@ def app_container():
                                 "dokus": get_list('List_CustomDJ_Documentaries'),
                                 "regex": get_list('List_CustomDJ_Documentaries_Regex'),
                             },
+                            "dd": {
+                                "feeds": get_list('List_CustomDD_Feeds'),
+                            },
                             "mbsj": {
                                 "staffeln": get_list('List_ContentAll_Seasons'),
                             }
@@ -1076,6 +1093,14 @@ def app_container():
                     data['dj']['dokus'].split('\n'))
                 ListDb("List_CustomDJ_Documentaries_Regex").store_list(
                     data['dj']['regex'].split('\n'))
+
+                try:
+                    replace_dd = 'https://' + CrawlerConfig('Hostnames').get('dd') + '/rss/'
+                except:
+                    replace_dd = 'https:///rss/'
+                    pass
+                ListDb("List_CustomDD_Feeds").store_list(
+                    data['dd']['feeds'].replace(replace_dd, "").split('\n'))
                 return "Success", 201
             except:
                 return "Failed", 400
